@@ -66,11 +66,8 @@ int main(int argc, char *argv[])
     }
     setenv("PULSE_PROP_media.role", "music", 1);
 
-    auto e = QProcessEnvironment::systemEnvironment();
-    QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
-    QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
-
-    if (XDG_SESSION_TYPE == QLatin1String("wayland") || WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) //是否开启wayland
+    Global::checkWaylandMode();
+    if (Global::isWaylandMode()) //是否开启wayland
         qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell"); //add wayland parameter
 
 #if (DTK_VERSION < DTK_VERSION_CHECK(5, 4, 0, 0))
@@ -115,6 +112,7 @@ int main(int argc, char *argv[])
     }
 
     app->loadTranslator();
+    Global::initPlaybackEngineType();
     MusicSettings::init();
 //    VlcDynamicInstance::VlcFunctionInstance();
 //    Player::getInstance();
@@ -123,11 +121,13 @@ int main(int argc, char *argv[])
     if (!OpenFilePaths.isEmpty()) {
         QStringList strList;
         for (QString str : OpenFilePaths) {
-            QUrl url = QUrl(str);
-            if (url.toLocalFile().isEmpty()) {
-                strList.append(str);
-            } else {
-                strList.append(url.toLocalFile());
+            if (QFile::exists(str)) {
+                QUrl url = QUrl::fromLocalFile(QDir::current().absoluteFilePath(str));
+                if (url.toLocalFile().isEmpty()) {
+                    strList.append(str);
+                } else {
+                    strList.append(url.toLocalFile());
+                }
             }
         }
         // 添加应用唯一性判断
@@ -137,7 +137,7 @@ int main(int argc, char *argv[])
         }
     }
 
-    if (!app->setSingleInstance("deepinmusic") || !checkOnly()) {
+    if (!app->setSingleInstance("deepinmusic") || !bc) {
         qDebug() << "another deepin music has started";
         QDBusInterface speechbus("org.mpris.MediaPlayer2.DeepinMusic",
                                  "/org/mpris/speech",
@@ -161,6 +161,7 @@ int main(int argc, char *argv[])
     }
 
     DApplicationSettings saveTheme;
+    Global::checkBoardVendorType();
     /*---Player instance init---*/
     MainFrame mainframe;
     int musicCount = DataBaseService::getInstance()->allMusicInfosCount();
@@ -178,21 +179,15 @@ int main(int argc, char *argv[])
 bool checkOnly()
 {
     //single
-    QString userName = QDir::homePath().section("/", -1, -1);
-    std::string path;
-    if (userName == "root") {
-        path = "/tmp/deepin-music/";
-    } else {
-        path = ("/home/" + userName + "/.cache/deepin/deepin-music/").toStdString();
-    }
-    QDir tdir(path.c_str());
+    QString path = DStandardPaths::writableLocation(QStandardPaths::AppConfigLocation);
+    QDir tdir(path);
     if (!tdir.exists()) {
-        bool ret =  tdir.mkpath(path.c_str());
-        qDebug() << ret ;
+        bool ret =  tdir.mkpath(path);
+        qDebug() << __func__ << ret ;
     }
 
-    path += "single";
-    int fd = open(path.c_str(), O_WRONLY | O_CREAT, 0644);
+    path += "/single";
+    int fd = open(path.toLocal8Bit().toStdString().c_str(), O_WRONLY | O_CREAT, 0644);
     int flock = lockf(fd, F_TLOCK, 0);
 
     if (fd == -1) {
