@@ -51,6 +51,7 @@
 #include <DSettingsWidgetFactory>
 #include <DSettingsOption>
 #include <DApplicationHelper>
+#include <DApplication>
 
 #include <unistd.h>
 #include "./core/musicsettings.h"
@@ -82,39 +83,6 @@ const QString s_PropertyViewnamePlay = "playList";
 static DSettingsDialog *equalizer = nullptr;
 using namespace Dtk::Widget;
 
-static bool showWindowfromDBus()
-{
-    QVariant v = DBusUtils::readDBusProperty("com.deepin.dde.daemon.Dock", "/com/deepin/dde/daemon/Dock",
-                                             "com.deepin.dde.daemon.Dock", "Entries");
-
-    if (!v.isValid())
-        return false;
-
-    QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath> >();
-
-    QString entryPath;
-    for (auto curPath : allSinkInputsList) {
-        QVariant nameV = DBusUtils::readDBusProperty("com.deepin.dde.daemon.Dock", curPath.path(),
-                                                     "com.deepin.dde.daemon.Dock.Entry", "Name");
-
-        if (!nameV.isValid() || nameV != Global::getAppName())
-            continue;
-
-        entryPath = curPath.path();
-        break;
-    }
-
-    QDBusInterface ainterface("com.deepin.dde.daemon.Dock", entryPath,
-                              "com.deepin.dde.daemon.Dock.Entry",
-                              QDBusConnection::sessionBus());
-    if (!ainterface.isValid()) {
-        return false;
-    }
-    ainterface.call(QLatin1String("Activate"), 1);
-
-    return true;
-}
-
 MainFrame::MainFrame()
 {
     setObjectName("MainFrame");
@@ -183,6 +151,8 @@ MainFrame::MainFrame()
             this, &MainFrame::slotImportFailed);
     connect(CommonService::getInstance(), &CommonService::signalShowPopupMessage,
             this, &MainFrame::showPopupMessage);
+    connect(CommonService::getInstance(), &CommonService::signalDecodingErrorMessage,
+            this, &MainFrame::decodingErrorMessage);
 
     connect(DataBaseService::getInstance(), &DataBaseService::signalPlayFromFileMaganager,
             this, &MainFrame::slotPlayFromFileMaganager);
@@ -192,31 +162,14 @@ MainFrame::MainFrame()
         qApp->quit();
     });
     connect(Player::getInstance()->getMpris(), &MprisPlayer::raiseRequested, this, [ = ]() {
-        auto e = QProcessEnvironment::systemEnvironment();
-        QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
-        QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
-        if (isVisible()) {
-            // 最小化和激活窗口
-            if (isMinimized()) {
-                // 使用dbus显示窗口
-                if ((XDG_SESSION_TYPE != QLatin1String("wayland") && !WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) || !showWindowfromDBus()) {
-                    this->titlebar()->setFocus();
-                    show();
-                    raise();
-                    activateWindow();
-                    this->restoreGeometry(m_geometryBa);
-                }
-            } else {
-                raise();
-                activateWindow();
-            }
-        } else {
-            // 使用dbus显示窗口
-            this->titlebar()->setFocus();
-            show();
-            raise();
-            activateWindow();
+        if (!isVisible()) {
+            restoreGeometry(m_geometryBa);
         }
+        // 使用dbus显示窗口
+        this->titlebar()->setFocus();
+        show();
+        raise();
+        activateWindow();
     });
 
     connect(CommonService::getInstance(), &CommonService::signalSwitchToView, this, &MainFrame::slotViewChanged);
@@ -245,6 +198,7 @@ MainFrame::MainFrame()
 
 MainFrame::~MainFrame()
 {
+    MusicSettings::release();
 }
 
 void MainFrame::initUI(bool showLoading)
@@ -331,7 +285,7 @@ void MainFrame::initMenuAndShortcut()
     pTitleMenu->addAction(m_newSonglistAction);
     pTitleMenu->addAction(m_addMusicFiles);
     pTitleMenu->addSeparator();
-    pTitleMenu->addAction(m_equalizer);
+    if (Global::playbackEngineType() == 1) pTitleMenu->addAction(m_equalizer);
     pTitleMenu->addAction(m_settings);
     pTitleMenu->addSeparator();
 
@@ -371,7 +325,7 @@ void MainFrame::initMenuAndShortcut()
 
     //初始化托盘
     auto playAction = new QAction(tr("Play/Pause"), this);
-    playAction->setEnabled(m_importWidget == nullptr);
+    playAction->setEnabled(DataBaseService::getInstance()->allMusicInfos().size() > 0);
     auto prevAction = new QAction(tr("Previous"), this);
     prevAction->setEnabled(false);
     auto nextAction = new QAction(tr("Next"), this);
@@ -437,27 +391,19 @@ void MainFrame::initMenuAndShortcut()
     connect(m_sysTrayIcon, &QSystemTrayIcon::activated,
     this, [ = ](QSystemTrayIcon::ActivationReason reason) {
         if (QSystemTrayIcon::Trigger == reason) {
-            auto e = QProcessEnvironment::systemEnvironment();
-            QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
-            QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
-            if (isVisible()) {
-                // 最小化和激活窗口
-                if (isMinimized() || !isActiveWindow()) {
-                    // 使用dbus显示窗口
-                    if ((XDG_SESSION_TYPE != QLatin1String("wayland") && !WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) || !showWindowfromDBus()) {
-                        this->titlebar()->setFocus();
-                        show();
-                        raise();
-                        activateWindow();
-                    }
-                } else {
-                    hide();
-                    showMinimized();
-                }
+            if (checkWindowVisible(Global::isWaylandMode())) {
+                m_preMaxFlag = isMaximized();
+                showMinimized();
             } else {
+                if (!isVisible()) {
+                    restoreGeometry(m_geometryBa);
+                }
+                show();
+                // 特性关闭后需要使用showNormal/showMaximized
+                if (m_preMaxFlag) showMaximized();
+                else showNormal();
                 // 使用dbus显示窗口
                 this->titlebar()->setFocus();
-                show();
                 raise();
                 activateWindow();
             }
@@ -465,6 +411,35 @@ void MainFrame::initMenuAndShortcut()
     });
 }
 
+bool MainFrame::checkWindowVisible(bool waylandMode)
+{
+    if (waylandMode) {
+        QVariant v = DBusUtils::readDBusProperty("com.deepin.dde.daemon.Dock", "/com/deepin/dde/daemon/Dock",
+                                                 "com.deepin.dde.daemon.Dock", "Entries");
+
+        if (!v.isValid()) return false;
+
+        QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath> >();
+
+        QString entryPath;
+        for (auto curPath : allSinkInputsList) {
+            QVariant nameV = DBusUtils::readDBusProperty("com.deepin.dde.daemon.Dock", curPath.path(),
+                                                         "com.deepin.dde.daemon.Dock.Entry", "Name");
+            if (!nameV.isValid() || nameV != Global::getAppName()) continue;
+
+            entryPath = curPath.path();
+            break;
+        }
+
+        QVariant isActive = DBusUtils::readDBusProperty("com.deepin.dde.daemon.Dock", entryPath,
+                                                        "com.deepin.dde.daemon.Dock.Entry", "IsActive");
+
+        return isActive.isValid() ? isActive.toBool() : false;
+    } else {
+        return (isVisible() && !isMinimized());
+    }
+}
+
 void MainFrame::initPadMenu()
 {
     // 公有函数防止重复调用引起的内存泄露
@@ -515,17 +490,17 @@ void MainFrame::autoStartToPlay()
     if (lastListPageSwitchType != AllSongListType)
         emit CommonService::getInstance()->signalSwitchToView(lastListPageSwitchType, lastplaypage);
     Player::getInstance()->reloadMetaList();
+    //读取均衡器使能开关配置
+    auto eqSwitch = MusicSettings::value("equalizer.all.switch").toBool();
+    if (eqSwitch) {
+        Player::getInstance()->initEqualizerCfg();
+    }
     if (!strOpenPath.isEmpty()) {
         //通知设置当前页面
         Player::getInstance()->setCurrentPlayListHash(lastplaypage, false);
         Player::getInstance()->init();
         return ;
     }
-    //读取均衡器使能开关配置
-    auto eqSwitch = MusicSettings::value("equalizer.all.switch").toBool();
-    if (eqSwitch) {
-        Player::getInstance()->initEqualizerCfg();
-    }
     auto lastMeta = MusicSettings::value("base.play.last_meta").toString();
     if (!lastMeta.isEmpty()) {
         bool bremember = MusicSettings::value("base.play.remember_progress").toBool();
@@ -611,6 +586,35 @@ void MainFrame::showPopupMessage(const QString &songListName, int selectCount, i
     DMessageManager::instance()->sendMessage(m_popupMessage, pDFloatingMessage);
 }
 
+void MainFrame::decodingErrorMessage()
+{
+    if (m_popupMessage == nullptr) {
+        m_popupMessage = new DWidget(this);
+        m_popupMessage->setAttribute(Qt::WA_TransparentForMouseEvents);
+        m_popupMessage->setVisible(true);
+        m_popupMessage->move(0, 0);
+    }
+
+    // 确保弹窗只显示一条
+    QList<QWidget *> oldMsgList = m_popupMessage->findChildren<QWidget *>("_d_message_float_deepin_music");
+    if (oldMsgList.size() > 0) {
+        oldMsgList.first()->deleteLater(); // auto delete
+    }
+    if (oldMsgList.size() >= 2)
+        return;
+
+    QIcon icon = QIcon::fromTheme("icon_warning");
+    DFloatingMessage *pDFloatingMessage = new DFloatingMessage(DFloatingMessage::MessageType::TransientType, m_popupMessage);
+    pDFloatingMessage->setObjectName("_d_message_float_deepin_music");
+    pDFloatingMessage->setBlurBackgroundEnabled(true);
+    pDFloatingMessage->setMessage(tr("Unsupported audio codec"));
+    pDFloatingMessage->setIcon(icon);
+    pDFloatingMessage->setDuration(2000);
+    m_popupMessage->resize(this->width(), this->height() - m_footerWidget->height());
+    m_popupMessage->raise();
+    DMessageManager::instance()->sendMessage(m_popupMessage, pDFloatingMessage);
+}
+
 void MainFrame::setThemeType(DGuiApplicationHelper::ColorType themeType)
 {
     if (getMusicContentWidget()) {
@@ -1037,7 +1041,7 @@ void MainFrame::showEvent(QShowEvent *event)
             qint32 restoredScreenWidth = 0;
             stream >> restoredScreenWidth;
         }
-        restoreGeometry(m_geometryBa);
+//        restoreGeometry(m_geometryBa);
     }
     this->setFocus();
 
@@ -1111,6 +1115,7 @@ void MainFrame::resizeEvent(QResizeEvent *e)
 
 void MainFrame::closeEvent(QCloseEvent *event)
 {
+    MusicSettings::setOption("base.play.volume", Player::getInstance()->getVolume());
     //保存进度
     auto curPosition = Player::getInstance()->getActiveMeta().offset;
     //是否记录最后播放位置
@@ -1137,6 +1142,7 @@ void MainFrame::closeEvent(QCloseEvent *event)
     case 1: {
         MusicSettings::setOption("base.play.state", int(windowState()));
         MusicSettings::setOption("base.close.is_close", true);
+//        MusicSettings::release();
         //退出时,stop当前音乐
         Player::getInstance()->stop(false);
         qApp->processEvents();
@@ -1159,6 +1165,7 @@ void MainFrame::closeEvent(QCloseEvent *event)
         }
         if (ccd.closeAction() == 1) {
             MusicSettings::setOption("base.close.is_close", true);
+//            MusicSettings::release();
             //退出时,stop当前音乐
             Player::getInstance()->stop(false);
             qApp->processEvents();
@@ -1172,7 +1179,12 @@ void MainFrame::closeEvent(QCloseEvent *event)
         break;
     }
 
+    // 最小化时隐藏关于窗口
+    if (qApp->aboutDialog() != nullptr && qApp->aboutDialog()->isVisible()) {
+        qApp->aboutDialog()->hide();
+    }
     this->setFocus();
+    m_preMaxFlag = isMaximized();
     DMainWindow::closeEvent(event);
 }
 
