@@ -39,31 +39,32 @@ DWIDGET_USE_NAMESPACE
 CloseConfirmDialog::CloseConfirmDialog(QWidget *parent) :
     Dtk::Widget::DDialog(parent)
 {
-    this->setFixedSize(380, 226);
+//    this->setFixedSize(380, 226);
     this->setSpacing(0);
     DWidget *contentFrame = new DWidget(this);
-    contentFrame->setFixedSize(380, 110);
+    QFontMetrics fm(DFontSizeManager::instance()->get(DFontSizeManager::T6, QFont::Normal));
+    contentFrame->setFixedSize(380, fm.height() * 4 + 30);
     contentFrame->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     auto contentLayout = new QVBoxLayout(contentFrame);
     contentLayout->setSpacing(10);
     contentLayout->setContentsMargins(0, 0, 0, 0);
 
     auto miniBt = new DRadioButton(tr("Minimize to system tray"), this);
-    miniBt->setFixedHeight(20);
+    miniBt->setFixedHeight(fm.height());
     miniBt->setObjectName("CloseConfirmDialogMini");
     DFontSizeManager::instance()->bind(miniBt, DFontSizeManager::T6, QFont::Normal);
 
     m_exitBt = new DRadioButton(tr("Exit"), this);
-    m_exitBt->setFixedHeight(20);
+    m_exitBt->setFixedHeight(fm.height());
     m_exitBt->setObjectName("CloseConfirmDialogExit");
     DFontSizeManager::instance()->bind(m_exitBt, DFontSizeManager::T6, QFont::Normal);
 
     m_remember = new DCheckBox(tr("Do not ask again"), this);
-    m_remember->setFixedHeight(20);
+    m_remember->setFixedHeight(fm.height());
     DFontSizeManager::instance()->bind(m_remember, DFontSizeManager::T6, QFont::Normal);
 
     DLabel *titleLabel = new DLabel(this);
-    titleLabel->setFixedHeight(20);
+    titleLabel->setFixedHeight(fm.height());
     titleLabel->setFixedWidth(380);
     titleLabel->setObjectName("MusicListDataTitle");
     titleLabel->setText(tr("Please choose your action"));
