@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug" sourcelanguage="en_US">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ug" sourcelanguage="en_US">
 <context>
     <name>AddMusicWidget</name>
     <message>
@@ -43,32 +45,32 @@
 <context>
     <name>CloseConfirmDialog</name>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="56"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="57"/>
         <source>Exit</source>
         <translation>چېكىنىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="51"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="52"/>
         <source>Minimize to system tray</source>
         <translation>سىستېما تەخسىگە كىچىكلىتىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="61"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="62"/>
         <source>Do not ask again</source>
         <translation>خاتالىق كۆرۈلدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="69"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="70"/>
         <source>Please choose your action</source>
         <translation>مەشغۇلاتىڭىزنى تاللاڭ</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="82"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="83"/>
         <source>Cancel</source>
         <translation>بىكار قىلىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="83"/>
+        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="84"/>
         <source>Confirm</source>
         <translation>جەزملەشتۈرۈش</translation>
     </message>
@@ -76,16 +78,16 @@
 <context>
     <name>DBOperate</name>
     <message>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="136"/>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="172"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="139"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="177"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="81"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="82"/>
         <source>Unknown album</source>
         <translation>نامەلۇم ئالبۇم</translation>
     </message>
     <message>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="139"/>
-        <location filename="../src/music-player/presenter/dboperate.cpp" line="175"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="142"/>
+        <location filename="../src/music-player/presenter/dboperate.cpp" line="180"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="77"/>
         <location filename="../src/music-player/presenter/databaseservice.cpp" line="78"/>
         <source>Unknown artist</source>
@@ -402,113 +404,118 @@
 <context>
     <name>MainFrame</name>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="311"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="264"/>
         <source>Add playlist</source>
         <translation>قويۇش تىزىملىكىگە قوشۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="150"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="313"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="475"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="118"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="266"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="416"/>
         <source>Add music</source>
         <translation>مۇزىكا قوشۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="314"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="267"/>
         <source>Equalizer</source>
         <translation>مۇۋازىنېتور</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="317"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="270"/>
         <source>Settings</source>
         <translation>تەڭشەك</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="320"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="273"/>
         <source>Dark theme</source>
         <translation>قاراڭغۇ تېما</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="324"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="379"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="277"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="332"/>
         <source>Exit</source>
         <translation>چېكىنىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="121"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="130"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="138"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="391"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="89"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="98"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="106"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="344"/>
         <source>Music</source>
         <translation>مۇزىكا</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="122"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="90"/>
         <source>Music is a local music player with beautiful design and simple functions.</source>
         <translation>مۇزىكا گۈزەل لايىھىلەش ۋە ئاددىي ئىقتىدارغا ئىگە يەرلىك مۇزىكا قويغۇچ.</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="155"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="123"/>
         <source>Select</source>
         <translation>تاللاش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="156"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="124"/>
         <source>Select All</source>
         <translation>ھەممىنى تاللاش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="157"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="125"/>
         <source>Done</source>
         <translation>تامام</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="373"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="326"/>
         <source>Play/Pause</source>
         <translation>قويۇش\توختۇتۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="375"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="328"/>
         <source>Previous</source>
         <translation>ئالدىنقى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="377"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="330"/>
         <source>Next</source>
         <translation>كېيىنكى </translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="573"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="514"/>
         <source>Successfully added to &quot;%1&quot;</source>
         <translation>مۇۋەپپەقىيەتلىك ھالدا &quot;%1&quot; گە قوشۇلدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="576"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="517"/>
         <source>Already added to the playlist</source>
         <translation>قويۇش تىزىملىكىگە بۇرۇنلا قوشۇلغان</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="579"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="520"/>
         <source>1 song added</source>
         <translation>1 ناخشا قوشۇلدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="581"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="522"/>
         <source>%1 songs added</source>
         <translation>%1 ناخشا قوشۇلدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="585"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="526"/>
         <source>A disc is connected</source>
         <translation>CD چېتىلغانلىقى بايقالدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="727"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="576"/>
+        <source>Unsupported audio codec</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="697"/>
         <source>OK</source>
         <translation>تامام</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="720"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="690"/>
         <source>Import failed, no valid music file found</source>
         <translation>ئەكىرىش مەغلۇپ بولدى ، ئۈنۈملۈك مۇزىكا ھۆججىتى تېپىلمىدى</translation>
     </message>
@@ -558,59 +565,59 @@
     <name>MusicListDataWidget</name>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="115"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1044"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1065"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1084"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1099"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1030"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1051"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1070"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1085"/>
         <source>No songs</source>
         <translation>ناخشا يوق</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="979"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="965"/>
         <source>Custom</source>
         <translation>ئادەت</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1046"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1032"/>
         <source>1 album - 1 song</source>
         <translation>1 پىلاستىنكا - 1 ناخشا</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1049"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1035"/>
         <source>%1 album - %2 songs</source>
         <translation>%1 پىلاستىنكا -%2 ناخشا</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1051"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1037"/>
         <source>%1 albums - %2 songs</source>
         <translation>%1 پىلاستىنكا -%2 ناخشا</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1067"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1053"/>
         <source>1 artist - 1 song</source>
         <translation>1 سەنئەتكار - 1 ناخشا</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1070"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1056"/>
         <source>%1 artist - %2 songs</source>
         <translation>%1 سەنئەتكار -%2 ناخشا</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1072"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1058"/>
         <source>%1 artists - %2 songs</source>
         <translation>%1 سەنئەتكار -%2 ناخشا</translation>
     </message>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="117"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1086"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1101"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1072"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1087"/>
         <source>1 song</source>
         <translation>1 ناخشا</translation>
     </message>
     <message>
         <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="119"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1088"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1103"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1074"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1089"/>
         <source>%1 songs</source>
         <translation>%1 ناخشا</translation>
     </message>
@@ -620,13 +627,13 @@
         <translation>ئىزدەش نەتىجىسى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1003"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="989"/>
         <source>No search results</source>
         <translation>ھېچقانداق ئىزدەش نەتىجىسى تىپىلمىدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="865"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="888"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="851"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="874"/>
         <source>All Music</source>
         <translation>ھەممە ناخشىلار</translation>
     </message>
@@ -636,35 +643,35 @@
         <translation>CD ناخشا تىزىملىكى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="933"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="948"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="963"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="980"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="919"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="934"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="949"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="966"/>
         <source>Time added</source>
         <translation>ۋاقىت قوشۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="934"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="966"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="983"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="920"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="952"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="969"/>
         <source>Album</source>
         <translation>پىلاستىنكا</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="949"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="965"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="982"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="935"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="951"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="968"/>
         <source>Artist</source>
         <translation>سەنئەتكار</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="964"/>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="981"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="950"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="967"/>
         <source>Title</source>
         <translation>تېما</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="839"/>
+        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="830"/>
         <source>Play All</source>
         <translation>ھەممىسىنى قويۇش</translation>
     </message>
@@ -693,68 +700,68 @@
 <context>
     <name>MusicSongListView</name>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="202"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="450"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="207"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="455"/>
         <source>Pause</source>
         <translation>تورمۇزلاش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="205"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="446"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="210"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="451"/>
         <source>Play</source>
         <translation>قويۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="211"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="448"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="216"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="453"/>
         <source>Add music</source>
         <translation>مۇزىكا قوشۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="212"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="452"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="217"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="457"/>
         <source>Rename</source>
         <translation>قايتا ئىسىم قويۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="213"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="334"/>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="454"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="218"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="339"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="459"/>
         <source>Delete</source>
         <translation>ئۆچۈرۈش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="296"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="301"/>
         <source>CD playlist</source>
         <translation>CD ناخشا تىزىملىكى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="326"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="331"/>
         <source>Are you sure you want to delete this playlist?</source>
         <translation>بۇ تىزىملىكنى ئۆچۈرمەكچىمۇ؟</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="333"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="338"/>
         <source>Cancel</source>
         <translation>بىكار قىلىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="571"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="576"/>
         <source>The CD has been removed</source>
         <translation>CD چىقىرىۋېتىلدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="575"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="580"/>
         <source>Play failed, as the CD has been removed</source>
         <translation>قويالمىدى! CD چىقىرىۋېتىلدى!</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="582"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="587"/>
         <source>OK</source>
         <translation>جەزىملەشتۈرۈش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="883"/>
+        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="964"/>
         <source>New playlist</source>
         <translation>يېڭى تىزىملىك قۇرۇش</translation>
     </message>
@@ -763,137 +770,137 @@
     <name>PlayListView</name>
     <message>
         <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="488"/>
-        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="835"/>
+        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="839"/>
         <source>Unknown artist</source>
         <translation>نامەلۇم سەنئەتچى</translation>
     </message>
     <message>
         <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="500"/>
-        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="847"/>
+        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="851"/>
         <source>Unknown album</source>
         <translation>نامەلۇم ئالبۇم</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1299"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1855"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1291"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1864"/>
         <source>Play queue</source>
         <translation>قويغۇچ ئۆچرىتى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1302"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1852"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1294"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1861"/>
         <source>My favorites</source>
         <translation>ياقتۇرغانلىرىم</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="580"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="581"/>
         <source>File is invalid or does not exist, load failed</source>
         <translation>ھۆججەت ئىناۋەتسىز ياكى مەۋجۇت ئەمەس ،قوشۇش مەغلۇپ بولدى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="581"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="582"/>
         <source>OK</source>
         <translation>جەزىملەشتۈرۈش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1340"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1332"/>
         <source>Play</source>
         <translation>قويۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1343"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1335"/>
         <source>Pause</source>
         <translation>تورمۇزلاش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1851"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1860"/>
         <source>Add to playlist</source>
         <translation>قويۇش تىزىملىكىگە قوشۇڭ</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1352"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1344"/>
         <source>Display in file manager</source>
         <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىلىدۇ</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1278"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1350"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1416"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1270"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1342"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1408"/>
         <source>Add to</source>
         <translation>غا قوشۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1306"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1298"/>
         <source>Create new playlist</source>
         <translation>يېڭى ناخشا تىزىملىكى قۇرۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1354"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1418"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1346"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1410"/>
         <source>Remove from play queue</source>
         <translation>قويغۇچ ئۆچرىتىدىن چىقىرۋىتىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1356"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1420"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1348"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1412"/>
         <source>Remove from playlist</source>
         <translation>قويۇش تىزىملىكىدىن ئۆچۈرۈڭ</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1359"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1422"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1351"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1414"/>
         <source>Delete from local disk</source>
         <translation>يەرلىك دىسكىدىن ئۆچۈرۈڭ</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1392"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1384"/>
         <source>Encoding</source>
         <translation>كودلاش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1396"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1388"/>
         <source>Song info</source>
         <translation>ناخشا ئۇچۇرى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1114"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1167"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1106"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1159"/>
         <source>Cancel</source>
         <translation>بىكار قىلىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1115"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1107"/>
         <source>Remove</source>
         <translation>چىقىرىۋېتىش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1118"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1110"/>
         <source>Are you sure you want to remove %1?</source>
         <translation>%1 نى ئۆچۈرمەكچىمۇ؟</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1120"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1112"/>
         <source>Are you sure you want to remove the selected %1 songs?</source>
         <translation>تاللانغان%1 ناخشىنى ئۆچۈرمەكچىمۇ؟</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1168"/>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1276"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1160"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1268"/>
         <source>Delete</source>
         <translation>ئۆچۈرۈش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1173"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1165"/>
         <source>Are you sure you want to delete %1?</source>
         <translation>%1 نى ئۆچۈرمەكچىمۇ؟</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1180"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1172"/>
         <source>Are you sure you want to delete the selected %1 songs?</source>
         <translation>تاللانغان%1 ناخشىنى ئۆچۈرمەكچىمۇ؟</translation>
     </message>
     <message>
-        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1181"/>
+        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1173"/>
         <source>The song files contained will also be deleted</source>
         <translation>مەزمۇندىكى ناخشا ھۆججەتلىرىمۇ ئۆچۈرۈلىدۇ</translation>
     </message>
@@ -901,12 +908,12 @@
 <context>
     <name>PlayQueueWidget</name>
     <message>
-        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="70"/>
+        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="71"/>
         <source>Play Queue</source>
         <translation>قويۇش تەرتىپى</translation>
     </message>
     <message>
-        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="83"/>
+        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="84"/>
         <source>Empty</source>
         <translation>قۇرۇق</translation>
     </message>
@@ -930,8 +937,8 @@
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="124"/>
-        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="128"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="92"/>
+        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="96"/>
         <source>Music</source>
         <translation>مۇزىكا</translation>
     </message>
@@ -1197,7 +1204,7 @@
         <translation>ھەممىسىنى قويۇش</translation>
     </message>
     <message>
-        <location filename="../src/music-player/mainFrame/subsonglistwidget.cpp" line="109"/>
+        <location filename="../src/music-player/mainFrame/subsonglistwidget.cpp" line="108"/>
         <source>Shuffle</source>
         <translation>ئۆزگەرتىش</translation>
     </message>
@@ -1210,4 +1217,4 @@
         <translation>ئىزدەش</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
